@@ -65,11 +65,21 @@ pub fn date_time_to_hour(date: i64) -> i64 {
     dt.hour() as i64
 }
 
+pub fn date_to_day_number_in_week(date: i64) -> u32 {
+    let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
+    parsed_date.weekday().number_from_sunday()
+}
+
 pub fn date_to_day_number_in_month(date: i64) -> u32 {
     let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
     parsed_date.day()
 }
 
+pub fn date_to_day_number_in_year(date: i64) -> u32 {
+    let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
+    parsed_date.ordinal()
+}
+
 pub fn date_to_day_name(date: i64) -> String {
     let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
 
@@ -108,6 +118,26 @@ pub fn date_to_month_name(date: i64) -> String {
     month_name.to_string()
 }
 
+pub fn date_to_quarter_index(date: i64) -> i64 {
+    let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
+    let month = parsed_date.month() as i64;
+    (month - 1) / 3 + 1
+}
+
+pub fn date_to_year(date: i64) -> i32 {
+    let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
+    parsed_date.year()
+}
+
+pub fn date_to_days_count(date: i64) -> i64 {
+    let parsed_date = NaiveDateTime::from_timestamp_opt(date, 0).unwrap();
+    let days_since_year_0 = parsed_date.ordinal0() as i64;
+    let year = parsed_date.year() as i64;
+    let leap_years = (year - 1) / 4 - (year - 1) / 100 + (year - 1) / 400;
+    let non_leap_years = year - leap_years;
+    365 * non_leap_years + 366 * leap_years + days_since_year_0
+}
+
 pub fn time_stamp_from_year_and_day(year: i32, day_of_year: u32) -> i64 {
     let date = NaiveDate::from_yo_opt(year, day_of_year).unwrap();
     let datetime = date.and_hms_opt(0, 0, 0).unwrap();
