@@ -43,6 +43,7 @@ lazy_static! {
         map.insert("concat_ws", text_concat_ws);
         map.insert("unicode", text_unicode);
         map.insert("strcmp", text_strcmp);
+        map.insert("quotename", text_quotename);
 
         // Date functions
         map.insert("current_date", date_current_date);
@@ -56,6 +57,12 @@ lazy_static! {
         map.insert("monthname", date_monthname);
         map.insert("hour", date_hour);
         map.insert("isdate", date_is_date);
+        map.insert("dayofweek", date_day_of_week);
+        map.insert("dayofmonth", date_day_of_month);
+        map.insert("dayofyear", date_day_of_year);
+        map.insert("quarter", date_quarter);
+        map.insert("year", date_year);
+        map.insert("to_days", date_to_days);
 
         // Numeric functions
         map.insert("abs", numeric_abs);
@@ -256,6 +263,13 @@ lazy_static! {
              },
         );
         map.insert("strcmp", Prototype { parameters: vec![DataType::Text, DataType::Text], result: DataType::Integer });
+        map.insert(
+            "quotename",
+            Prototype {
+                parameters: vec![DataType::Text, DataType::Optional(Box::new(DataType::Text))],
+                result: DataType::Text
+            }
+        );
 
         // Date functions
         map.insert(
@@ -335,6 +349,48 @@ lazy_static! {
                 result: DataType::Boolean,
             }
         );
+        map.insert(
+            "dayofweek",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
+        map.insert(
+            "dayofmonth",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
+        map.insert(
+            "dayofyear",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
+        map.insert(
+            "quarter",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
+        map.insert(
+            "year",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
+        map.insert(
+            "to_days",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
         // Numeric functions
         map.insert(
             "abs",
@@ -720,6 +776,21 @@ fn text_strcmp(inputs: &[Value]) -> Value {
     })
 }
 
+fn text_quotename(inputs: &[Value]) -> Value {
+    let str = inputs[0].as_text();
+    let quote = inputs
+        .get(1)
+        .map(Value::as_text)
+        .map(|str| str.chars().collect())
+        .unwrap_or_else(|| vec!['[', ']']);
+
+    match quote.as_slice() {
+        [single] => Value::Text(format!("{single}{str}{single}")),
+        [start, end] => Value::Text(format!("{start}{str}{end}")),
+        _ => Value::Null,
+    }
+}
+
 // Date functions
 
 fn date_current_date(_inputs: &[Value]) -> Value {
@@ -779,6 +850,36 @@ fn date_is_date(inputs: &[Value]) -> Value {
     Value::Boolean(inputs[0].data_type().is_date())
 }
 
+fn date_day_of_week(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(date_utils::date_to_day_number_in_week(date).into())
+}
+
+fn date_day_of_month(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(date_utils::date_to_day_number_in_month(date).into())
+}
+
+fn date_day_of_year(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(date_utils::date_to_day_number_in_year(date).into())
+}
+
+fn date_quarter(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(date_utils::date_to_quarter_index(date))
+}
+
+fn date_year(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(date_utils::date_to_year(date).into())
+}
+
+fn date_to_days(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(date_utils::date_to_days_count(date))
+}
+
 // Numeric functions
 
 fn numeric_abs(inputs: &[Value]) -> Value {
