@@ -9,9 +9,11 @@ use gitql_ast::environment::Environment;
 use gitql_ast::object::GitQLObject;
 use gitql_ast::object::Group;
 use gitql_ast::object::Row;
+use gitql_ast::statement::DescribeStatement;
 use gitql_ast::statement::GQLQuery;
 use gitql_ast::statement::Query;
 use gitql_ast::statement::SelectStatement;
+use gitql_ast::value::Value;
 
 use crate::data_provider::DataProvider;
 use crate::engine_executor::execute_global_variable_statement;
@@ -45,6 +47,8 @@ pub fn evaluate(
             execute_global_variable_statement(env, &global_variable)?;
             Ok(EvaluationResult::SetGlobalVariable)
         }
+        Query::Describe(describe_statement) => evaluate_describe_query(env, describe_statement),
+        Query::ShowTables => evaluate_show_tables_query(env),
     }
 }
 
@@ -178,3 +182,64 @@ fn apply_distinct_on_objects_group(gitql_object: &mut GitQLObject, hidden_select
         gitql_object.groups[0].rows.append(&mut new_objects.rows);
     }
 }
+
+pub fn evaluate_describe_query(
+    env: &mut Environment,
+    stmt: DescribeStatement,
+) -> Result<EvaluationResult, String> {
+    let mut gitql_object = GitQLObject::default();
+    let hidden_selections = vec![];
+
+    let table_fields = env
+        .schema
+        .tables_fields_names
+        .get(&stmt.table_name.as_str());
+
+    if table_fields.is_none() {
+        return Err(format!("Table {:?} doesnt exist", &stmt.table_name));
+    }
+
+    let table_fields = table_fields.unwrap();
+
+    for title in ["Field", "Type"] {
+        gitql_object.titles.push(title.to_owned());
+    }
+
+    for field in table_fields {
+        let value = env.schema.tables_fields_types.get(field).unwrap();
+
+        gitql_object.groups.push(Group {
+            rows: vec![Row {
+                values: vec![
+                    Value::Text(field.to_owned().to_owned()),
+                    Value::Text(value.to_string()),
+                ],
+            }],
+        })
+    }
+
+    Ok(EvaluationResult::SelectedGroups(
+        gitql_object,
+        hidden_selections,
+    ))
+}
+
+pub fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult, String> {
+    let mut gitql_object = GitQLObject::default();
+    let hidden_selections = vec![];
+
+    gitql_object.titles.push("Tables".to_owned());
+
+    for table in env.schema.tables_fields_names.keys() {
+        gitql_object.groups.push(Group {
+            rows: vec![Row {
+                values: vec![Value::Text(table.to_owned().to_owned())],
+            }],
+        })
+    }
+
+    Ok(EvaluationResult::SelectedGroups(
+        gitql_object,
+        hidden_selections,
+    ))
+}
