@@ -16,6 +16,8 @@ pub enum TokenKind {
     Not,
     Like,
     Glob,
+    Describe,
+    Show,
 
     Case,
     When,
@@ -644,7 +646,7 @@ fn consume_global_variable_name(
         *pos += 1;
     }
 
-    // Identifier is be case-insensitive by default, convert to lowercase to be easy to compare and lookup
+    // Identifier is being case-insensitive by default, convert to lowercase to be easy to compare and lookup
     let literal = &chars[*start..*pos];
     let string = String::from_utf8(literal.iter().map(|&c| c as u8).collect())
         .unwrap()
@@ -667,7 +669,7 @@ fn consume_identifier(chars: &[char], pos: &mut usize, start: &mut usize) -> Tok
         *pos += 1;
     }
 
-    // Identifier is be case-insensitive by default, convert to lowercase to be easy to compare and lookup
+    // Identifier is being case-insensitive by default, convert to lowercase to be easy to compare and lookup
     let literal = &chars[*start..*pos];
     let string = String::from_utf8(literal.iter().map(|&c| c as u8).collect())
         .unwrap()
@@ -808,7 +810,7 @@ fn consume_octal_number(
     start: &mut usize,
 ) -> Result<Token, Box<Diagnostic>> {
     let mut has_digit = false;
-    while *pos < chars.len() && ((chars[*pos] >= '0' || chars[*pos] < '8') || chars[*pos] == '_') {
+    while *pos < chars.len() && ((chars[*pos] >= '0' && chars[*pos] < '8') || chars[*pos] == '_') {
         *pos += 1;
         has_digit = true;
     }
@@ -980,6 +982,8 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "not" => TokenKind::Not,
         "like" => TokenKind::Like,
         "glob" => TokenKind::Glob,
+        "describe" => TokenKind::Describe,
+        "show" => TokenKind::Show,
 
         // Logical Operators
         "or" => TokenKind::LogicalOr,
